# lingo - payment and billing system
# Copyright (C) 2023  Entr'ouvert
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from django.contrib.auth.mixins import LoginRequiredMixin
from django.shortcuts import get_object_or_404
from django.views.generic import TemplateView, View

from lingo.basket.models import Basket
from lingo.invoicing.views.utils import PDFMixin


class BasketDetailView(LoginRequiredMixin, TemplateView):
    template_name = 'lingo/basket/basket_detail.html'

    def get_context_data(self, **kwargs):
        nameid = self.request.user.get_name_id()
        basket = Basket.objects.filter(
            status__in=['open', 'tobepaid'],
            payer_nameid=nameid,
        ).first()
        kwargs['basket'] = basket
        return super().get_context_data(**kwargs)


basket_detail = BasketDetailView.as_view()


class BasketInvoicePDFView(LoginRequiredMixin, PDFMixin, View):
    def get_object(self):
        nameid = self.request.user.get_name_id()
        basket = get_object_or_404(
            Basket,
            status__in=['open', 'tobepaid'],
            payer_nameid=nameid,
        )
        return basket.draft_invoice


basket_invoice_pdf = BasketInvoicePDFView.as_view()
